import { tap, expect } from '@pushrocks/tapbundle';
import { Qenv } from '@pushrocks/qenv';

const testQenv = new Qenv(process.cwd(), process.cwd() + '/.nogit/');

console.log(process.memoryUsage());

// the tested module
import * as smartdata from '../ts/index';

import * as mongoPlugin from 'mongodb-memory-server';
import { smartunique } from '../ts/smartdata.plugins';

// =======================================
// Connecting to the database server
// =======================================

let testDb: smartdata.SmartdataDb;
let smartdataOptions: smartdata.IMongoDescriptor;
let mongod: mongoPlugin.MongoMemoryServer;

tap.test('should create a testinstance as database', async () => {
  mongod = new mongoPlugin.MongoMemoryServer({});
  console.log('created mongod instance');
  await mongod._startUpInstance().catch((err) => {
    console.log(err);
  });
  console.log('mongod started');
  smartdataOptions = {
    mongoDbName: await mongod.getDbName(),
    mongoDbPass: '',
    mongoDbUrl: await mongod.getUri(),
  };
  console.log(smartdataOptions);
  testDb = new smartdata.SmartdataDb(smartdataOptions);
  await testDb.init();
});

let easyStore: smartdata.EasyStore<{
  key1: string;
  key2: string;
}>;

tap.test('should create an easystore', async () => {
  easyStore = await testDb.createEasyStore('hellothere');
  await easyStore.writeKey('key1', 'hello');
  const retrievedKey = await easyStore.readKey('key1');
  expect(retrievedKey).to.equal('hello');
});

tap.test('close', async () => {
  testDb.close();
  mongod.stop();
  setTimeout(() => {
    process.exit(0);
  }, 1000);
});

tap.start();
